==> 0.1.3.tar.gz: ios/Classes/other/YDHomePageViewController.m <==
//
//  YDHomePageViewController.m
//  CLRealPersonDemo
//
//  Created by ydong on 2021/6/5.
//  Copyright © 2021年 ydong. All rights reserved.
//

#import "YDHomePageViewController.h"
#import "YDVideoViewController.h"

#import "YDDemoDefines.h"
#import "Masonry/Masonry.h"
#import "UIColor+YDLiveDetect.h"

@implementation YDHomePageViewController

-(void)dealloc{
    NSLog(@"homePage is dealloc");
}

- (void)viewDidLoad {
    self.title = @"活体检测";
    self.navigationController.navigationBar.tintColor = UIColor.blackColor;
    self.view.backgroundColor = [UIColor whiteColor];
    [self createSubview];
}

-(void)back {
    [self.navigationController.view removeFromSuperview];
    [self.navigationController removeFromParentViewController];
}

- (void)startLiveDetect {
    WeakSelf(self);
    YDVideoViewController *vc = [[YDVideoViewController alloc] init];
    vc.showResult = self.showResult;
    vc.distance = self.distance;
    vc.resultCallback = ^(NSString * _Nonnull resultString) {
        if (weakSelf.reslutCallback) {
            weakSelf.reslutCallback(resultString);
            [weakSelf.navigationController.view removeFromSuperview];
            [weakSelf.navigationController removeFromParentViewController];
        }        
    };
    [self.navigationController pushViewController:vc animated:YES];
}

-(void)createSubview{
    
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithImage:[UIImage imageNamed:@"ico_back"] style:(UIBarButtonItemStyleDone) target:self action:@selector(back)];
    
    UIImageView *bgImage = [[UIImageView alloc] init];
    bgImage.image = [UIImage imageNamed:@"bgRect"];
    [self.view addSubview:bgImage];
    [bgImage mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(statusBarHeight+44);
        make.left.right.offset(0);
        make.height.offset(503);
    }];
    
    UILabel *firstL = [[UILabel alloc] init];
    firstL.text = @"拍摄您本人人脸，请保证正对手机，光线充足";
    firstL.font = [UIFont fontWithName:@"PingFangSC-Semibold" size:15];
    firstL.textColor = [UIColor whiteColor];
    firstL.textAlignment = NSTextAlignmentCenter;
    [self.view addSubview:firstL];
    [firstL mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(30 + statusBarHeight+44);
        make.left.right.equalTo(self.view);
        make.height.offset(21);
    }];
    
    UILabel *secondL = [[UILabel alloc] init];
    secondL.text = @"请确认由本人亲自操作";
    secondL.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    secondL.textColor = [UIColor whiteColor];
    secondL.textAlignment = NSTextAlignmentCenter;
    [self.view addSubview:secondL];
    [secondL mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(firstL.mas_bottom).offset(14);
        make.left.right.equalTo(self.view);
        make.height.offset(21);
    }];
    
    UIImageView *logoImage = [[UIImageView alloc] init];
    logoImage.image = [UIImage imageNamed:@"325"];
    [self.view addSubview:logoImage];
    [logoImage mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(secondL.mas_bottom).offset(20);
        make.centerX.equalTo(self.view);
        make.width.height.offset(210);
    }];
    
    UIView *centerView = [[UIView alloc] init];
    centerView.backgroundColor = UIColor.whiteColor;
    centerView.layer.cornerRadius = 6;
    centerView.layer.shadowColor = [UIColor lightGrayColor].CGColor;
    centerView.layer.shadowOpacity = 0.6;
    centerView.layer.shadowOffset = CGSizeMake(0, 2);
    [self.view addSubview:centerView];
    
    [centerView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(logoImage.mas_bottom).offset(40);
        make.left.offset(32);
        make.right.offset(-32);
        make.height.offset(157);
    }];
    
    UIImageView *arrow1 = [[UIImageView alloc] init];
    arrow1.image = [UIImage imageNamed:@"arrow_right"];
    arrow1.contentMode = UIViewContentModeScaleAspectFit;
    [centerView addSubview:arrow1];
    [arrow1 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(29);
        make.left.offset(50);
        make.width.height.offset(20);
    }];
    
    UILabel *label1 = [[UILabel alloc] init];
    label1.text = @"保证光线充足";
    label1.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    label1.textColor = [UIColor colorWithHexString:@"#606266"];
    [centerView addSubview:label1];
    [label1 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.height.equalTo(arrow1);
        make.left.equalTo(arrow1.mas_right).offset(16);
        make.right.equalTo(centerView.mas_right).offset(-20);
    }];
    
    UIImageView *arrow2 = [[UIImageView alloc] init];
    arrow2.image = [UIImage imageNamed:@"arrow_right"];
    arrow2.contentMode = UIViewContentModeScaleAspectFit;
    [centerView addSubview:arrow2];
    [arrow2 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(arrow1.mas_bottom).offset(23);
        make.left.width.height.equalTo(arrow1);
    }];
    
    UILabel *label2 = [[UILabel alloc] init];
    label2.text = @"直握手机，正视镜头";
    label2.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    label2.textColor = [UIColor colorWithHexString:@"#606266"];
    [centerView addSubview:label2];
    [label2 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.height.equalTo(arrow2);
        make.left.equalTo(arrow2.mas_right).offset(16);
        make.right.equalTo(centerView.mas_right).offset(-20);
    }];
    
    UIImageView *arrow3 = [[UIImageView alloc] init];
    arrow3.image = [UIImage imageNamed:@"arrow_right"];
    arrow3.contentMode = UIViewContentModeScaleAspectFit;
    [centerView addSubview:arrow3];
    [arrow3 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(arrow2.mas_bottom).offset(23);
        make.left.width.height.equalTo(arrow2);
    }];
    
    UILabel *label3 = [[UILabel alloc] init];
    label3.text = @"跟随提示做出动作";
    label3.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    label3.textColor = [UIColor colorWithHexString:@"#606266"];
    [centerView addSubview:label3];
    [label3 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.height.equalTo(arrow3);
        make.left.equalTo(arrow3.mas_right).offset(16);
        make.right.equalTo(centerView.mas_right).offset(-20);
    }];
    
    UIButton *startRealButton = [UIButton buttonWithType:UIButtonTypeCustom];
    [startRealButton setTitle:@"采集本人人脸" forState:UIControlStateNormal];
    [startRealButton setTitleColor:UIColorFromHex(0xffffff) forState:UIControlStateNormal];
    startRealButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    startRealButton.layer.cornerRadius = 44.0/2;
    startRealButton.layer.masksToBounds = YES;
    [startRealButton setBackgroundColor:[UIColor colorWithHexString:@"#1183F7"]];
    [startRealButton addTarget:self action:@selector(startLiveDetect) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:startRealButton];
    [startRealButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(centerView.mas_bottom).offset(40);
        make.left.offset(32);
        make.right.offset(-32);
        make.height.equalTo(@(44));
    }];
}

@end

==> 0.1.7.tar.gz: ios/Classes/other/YDHomePageViewController.m <==
//
//  YDHomePageViewController.m
//  
//
//  Created by ydong on 2021/6/5.
//  Copyright © 2021年 ydong. All rights reserved.
//

#import "YDHomePageViewController.h"
#import "YDVideoViewController.h"

#import "YDDemoDefines.h"
#import "Masonry/Masonry.h"
#import "UIColor+YDLiveDetect.h"
#import "YDLocalizationManager.h"

@implementation YDHomePageViewController

-(void)dealloc{
    NSLog(@"homePage is dealloc");
}

- (void)viewDidLoad {
    self.title = [self returnLocaleString:@"alive_check"];
    self.navigationController.navigationBar.tintColor = UIColor.blackColor;
    self.view.backgroundColor = [UIColor whiteColor];
    [self createSubview];
}

-(void)back {
    [self.navigationController dismissViewControllerAnimated:YES completion:nil];
}

- (void)startLiveDetect {
    WeakSelf(self);
    YDVideoViewController *vc = [[YDVideoViewController alloc] init];
    vc.showResult = self.showResult;
    vc.distance = self.distance;
    vc.language = _language;
    vc.resultCallback = ^(NSString * _Nonnull resultString) {
        if (weakSelf.reslutCallback) {
            weakSelf.reslutCallback(resultString);
            [weakSelf.navigationController dismissViewControllerAnimated:YES completion:nil];
        }        
    };
    [self.navigationController pushViewController:vc animated:YES];
}

-(void)createSubview{
    
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithImage:[UIImage imageNamed:@"ico_back"] style:(UIBarButtonItemStyleDone) target:self action:@selector(back)];
    
    UIImageView *bgImage = [[UIImageView alloc] init];
    bgImage.image = [UIImage imageNamed:@"bgRect"];
    [self.view addSubview:bgImage];
    [bgImage mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(statusBarHeight+44);
        make.left.right.offset(0);
        make.height.offset(503);
    }];
    
    UILabel *firstL = [[UILabel alloc] init];
    firstL.text = [self returnLocaleString:@"alive_all"];
    firstL.font = [UIFont fontWithName:@"PingFangSC-Semibold" size:15];
    firstL.textColor = [UIColor whiteColor];
    firstL.textAlignment = NSTextAlignmentCenter;
    [self.view addSubview:firstL];
    [firstL mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(30 + statusBarHeight+44);
        make.left.right.equalTo(self.view);
        make.height.offset(21);
    }];
    
    UILabel *secondL = [[UILabel alloc] init];
    secondL.text = [self returnLocaleString:@"alive_sure_self"];
    secondL.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    secondL.textColor = [UIColor whiteColor];
    secondL.textAlignment = NSTextAlignmentCenter;
    [self.view addSubview:secondL];
    [secondL mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(firstL.mas_bottom).offset(14);
        make.left.right.equalTo(self.view);
        make.height.offset(21);
    }];
    
    UIImageView *logoImage = [[UIImageView alloc] init];
    logoImage.image = [UIImage imageNamed:@"325"];
    [self.view addSubview:logoImage];
    [logoImage mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(secondL.mas_bottom).offset(20);
        make.centerX.equalTo(self.view);
        make.width.height.offset(210);
    }];
    
    UIView *centerView = [[UIView alloc] init];
    centerView.backgroundColor = UIColor.whiteColor;
    centerView.layer.cornerRadius = 6;
    centerView.layer.shadowColor = [UIColor lightGrayColor].CGColor;
    centerView.layer.shadowOpacity = 0.6;
    centerView.layer.shadowOffset = CGSizeMake(0, 2);
    [self.view addSubview:centerView];
    
    [centerView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(logoImage.mas_bottom).offset(40);
        make.left.offset(32);
        make.right.offset(-32);
        make.height.offset(157);
    }];
    
    UIImageView *arrow1 = [[UIImageView alloc] init];
    arrow1.image = [UIImage imageNamed:@"arrow_right"];
    arrow1.contentMode = UIViewContentModeScaleAspectFit;
    [centerView addSubview:arrow1];
    [arrow1 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(29);
        make.left.offset(50);
        make.width.height.offset(20);
    }];
    
    UILabel *label1 = [[UILabel alloc] init];
    label1.text = [self returnLocaleString:@"alive_sunshine"];
    label1.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    label1.textColor = [UIColor colorWithHexString:@"#606266"];
    [centerView addSubview:label1];
    [label1 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.height.equalTo(arrow1);
        make.left.equalTo(arrow1.mas_right).offset(16);
        make.right.equalTo(centerView.mas_right).offset(-20);
    }];
    
    UIImageView *arrow2 = [[UIImageView alloc] init];
    arrow2.image = [UIImage imageNamed:@"arrow_right"];
    arrow2.contentMode = UIViewContentModeScaleAspectFit;
    [centerView addSubview:arrow2];
    [arrow2 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(arrow1.mas_bottom).offset(23);
        make.left.width.height.equalTo(arrow1);
    }];
    
    UILabel *label2 = [[UILabel alloc] init];
    label2.text = [self returnLocaleString:@"alive_portrait"];
    label2.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    label2.textColor = [UIColor colorWithHexString:@"#606266"];
    [centerView addSubview:label2];
    [label2 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.height.equalTo(arrow2);
        make.left.equalTo(arrow2.mas_right).offset(16);
        make.right.equalTo(centerView.mas_right).offset(-20);
    }];
    
    UIImageView *arrow3 = [[UIImageView alloc] init];
    arrow3.image = [UIImage imageNamed:@"arrow_right"];
    arrow3.contentMode = UIViewContentModeScaleAspectFit;
    [centerView addSubview:arrow3];
    [arrow3 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(arrow2.mas_bottom).offset(23);
        make.left.width.height.equalTo(arrow2);
    }];
    
    UILabel *label3 = [[UILabel alloc] init];
    label3.text = [self returnLocaleString:@"alive_action"];
    label3.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    label3.textColor = [UIColor colorWithHexString:@"#606266"];
    [centerView addSubview:label3];
    [label3 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.height.equalTo(arrow3);
        make.left.equalTo(arrow3.mas_right).offset(16);
        make.right.equalTo(centerView.mas_right).offset(-20);
    }];
    
    UIButton *startRealButton = [UIButton buttonWithType:UIButtonTypeCustom];
    [startRealButton setTitle:[self returnLocaleString:@"alive_self"] forState:UIControlStateNormal];
    [startRealButton setTitleColor:UIColorFromHex(0xffffff) forState:UIControlStateNormal];
    startRealButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15];
    startRealButton.layer.cornerRadius = 44.0/2;
    startRealButton.layer.masksToBounds = YES;
    [startRealButton setBackgroundColor:[UIColor colorWithHexString:@"#1183F7"]];
    [startRealButton addTarget:self action:@selector(startLiveDetect) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:startRealButton];
    [startRealButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(centerView.mas_bottom).offset(40);
        make.left.offset(32);
        make.right.offset(-32);
        make.height.equalTo(@(44));
    }];
}

-(NSString *)returnLocaleString:(NSString *)key{
    return [YDLocalizationManager localizedStringForKey:key language:_language];
}

@end
